summaryrefslogtreecommitdiff
path: root/framework/source/jobs
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/jobs')
-rw-r--r--framework/source/jobs/job.cxx4
-rw-r--r--framework/source/jobs/jobdata.cxx8
-rw-r--r--framework/source/jobs/jobdispatch.cxx2
-rw-r--r--framework/source/jobs/jobresult.cxx6
4 files changed, 10 insertions, 10 deletions
diff --git a/framework/source/jobs/jobdata.cxx b/framework/source/jobs/jobdata.cxx
index 3fb1b958baf9..3d7972955a06 100644
--- a/framework/source/jobs/jobdata.cxx
+++ b/framework/source/jobs/jobdata.cxx
@@ -67,7 +67,7 @@ const sal_Char* JobData::PROP_CONTEXT = "Context"
/**
@short standard ctor
@descr It initialize this new instance.
- But for real working it's neccessary to call setAlias() or setService() later.
+ But for real working it's necessary to call setAlias() or setService() later.
Because we need the job data ...
@param rxContext
@@ -138,7 +138,7 @@ JobData::~JobData()
//________________________________
/**
@short initalize this instance as a job with configuration
- @descr They given alias can be used to address some configuraton data.
+ @descr They given alias can be used to address some configuration data.
We read it and fill our internal structures. Of course old information
will be lost doing so.
@@ -482,7 +482,7 @@ css::uno::Sequence< css::beans::NamedValue > JobData::getConfig() const
@short return information, if this job is part of the global configuration package
org.openoffice.Office.Jobs
@descr Because jobs can be executed by the dispatch framework using an uno service name
- directly - an executed job must not have any configuration realy. Such jobs
+ directly - an executed job must not have any configuration really. Such jobs
must provide the right interfaces only! But after finishing jobs can return
some information (e.g. for updating her configuration ...). We must know
if such request is valid or not then.
@@ -704,7 +704,7 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
But note: that does not set defaults for internal used members, which
does not relate to any job property! e.g. the reference to the global
uno service manager. Such information is used for internal processes only
- and are neccessary for our work.
+ and are necessary for our work.
*/
void JobData::impl_reset()
{
diff --git a/framework/source/jobs/jobdispatch.cxx b/framework/source/jobs/jobdispatch.cxx
index b8f50508dbf0..4b069d93407a 100644
--- a/framework/source/jobs/jobdispatch.cxx
+++ b/framework/source/jobs/jobdispatch.cxx
@@ -251,7 +251,7 @@ void JobDispatch::impl_dispatchEvent( /*IN*/ const OUString&
// no jobs ... no execution
// But a may given listener will know something ...
// I think this operaton was finished successfully.
- // It's not realy an error, if no registered jobs could be located.
+ // It's not really an error, if no registered jobs could be located.
// Step over all found jobs and execute it
int nExecutedJobs=0;
for (int j=0; j<lJobs.getLength(); ++j)
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index 18ea4ff53d7f..2d0bc573ddc8 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -382,7 +382,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
}
// get the configuration data from the job data container ... if possible
// Means: if this job has any configuration data. Note: only realy
// filled lists will be set to the return structure at the end of this method.
css::uno::Sequence< css::beans::NamedValue > lConfigArgs ;
css::uno::Sequence< css::beans::NamedValue > lJobConfigArgs;
@@ -737,7 +737,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) thro
Then we had not throwed a veto exception. But now we must agree with this situation and break
all our internal processes. Its not a good idea to mark this instance as non startable any longer
inside queryTermination() if no job was unning too. Because that would disable this job and may
- the office does not realy shutdownm, because another listener has thrown the suitable exception.
+ the office does not really shutdownm, because another listener has thrown the suitable exception.
@param aEvent
describes the broadcaster and must be the desktop instance
@@ -382,7 +382,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
}
// get the configuration data from the job data container ... if possible
- // Means: if this job has any configuration data. Note: only realy
+ // Means: if this job has any configuration data. Note: only really
// filled lists will be set to the return structure at the end of this method.
css::uno::Sequence< css::beans::NamedValue > lConfigArgs ;
diff --git a/framework/source/jobs/jobresult.cxx b/framework/source/jobs/jobresult.cxx
index 5c45ca9ab4fa..d972326bf714 100644
--- a/framework/source/jobs/jobresult.cxx
+++ b/framework/source/jobs/jobresult.cxx
@@ -60,7 +60,7 @@ JobResult::JobResult()
<br>
The returned list of (for this generic implementation unknown!)
properties, will be written directly to the configuration and replace
- any old values there. There will no check for changes and we doesn't
+ any old values there. There will no check for changes and we don't
support any mege feature here. They are written only. The job has
to modify this list.
</li>
@@ -151,7 +151,7 @@ JobResult::JobResult( const JobResult& rCopy )
*/
JobResult::~JobResult()
{
// Nothing realy to do here.
}
//________________________________
@@ -179,7 +179,7 @@ void JobResult::operator=( const JobResult& rCopy )
/**
@short checks for existing parts of the analyzed result
@descr The internal flag mask was set after analyzing of the pure result.
- An user of us can check here, if the required part was realy part
+ An user of us can check here, if the required part was really part
of this result. Otherwhise it would use invalid information ...
by using our other members!
@@ -151,7 +151,7 @@ JobResult::JobResult( const JobResult& rCopy )
JobResult::~JobResult()
{
- // Nothing realy to do here.
+ // Nothing really to do here.
}
//________________________________